/*
  Copyright 1999 Brian H. Trammell (brian@altara.org)

  This software (and its source code) are freely usable, modifiable,
  and redistributable under the terms of the GNU General Public License, 
  available at http://www.gnu.org/copyleft/gpl.html.

  This software is released without any warranty whatsoever.

  Note this library software is NOT distributed under the GNU LGPL; if you 
  link an application with this software, it is ILLEGAL to distribute it
  under any terms incompatible with the GNU GPL.
*/

package org.altara.netlib;

import java.io.*;
import java.net.*;

/**
  This class represents a mail message that can send itself using an SMTP
  server. Create a new message with the default constructor, then add lines
  to the body to fill out the message. Invoke sendMessage() to make the
  message attempt to send itself.

  This is an example protocol implementation for Altara Netlib for Java,
  and is the engine behind email notification in MARS.
*/

public class SMTPMessage extends AbstractClient {

String from, to, subject;
StringBuffer data;
    
    /**
       Creates a new SMTP message with the specified From address, To address,
       and subject line, that will be sent via the specified SMTP server.
       
       @param server the SMTP server to connect to
       @param from the message's sender address
       @param to the message's recipient address
       @param subject the message's subject line
    */

    public SMTPMessage (String server, String from, String to, String subject){
	super(server, 25);                      // set up the smtp client
	this.from = from;                       // set addresses and subject
	this.to = to;
	this.subject = subject;
	data = new StringBuffer();              // new data buffer
    }

    /**
       Adds a line of text to this SMTP message.
       
       @param line the line to add.
    */

    public void addLine(String line) {
	data.append(line);
	data.append("\n");
    }

    /**
       Attempt to send the message. 
       
       @return true if the message was successfully sent, false otherwise.
    */

    public boolean sendMessage()
    throws UnknownHostException, IOException {

	try {
	    connect();                         // Open the SMTP connection
	    
	    send("MAIL From: "+from+"\n");     // Send envelope
	    if (waitFor("250",3) == false)
		return false;

	    send("RCPT To: "+to+"\n");
	    if (waitFor("250",3) == false)
		return false;

	    send("DATA\n");                    // Start data section
	    if (waitFor("354",3) == false)
		return false;
	
	    // Send 822 headers
	    send("From: "+from+"\nSubject: "+subject+"\n\n");
	    // Send message body
	    send(data.toString());
	    
	    send(".\n");                       // End data section
	    if (waitFor("250",3) == false)
		return false;

	    send("QUIT\n");                    // Break the SMTP connection
	    close();
	} catch (Exception ex) { return false; }
	
	return true;                           // signal successful send
    }
    
}
